package HTML::Display::Phoenix;
use strict;
use parent 'HTML::Display::TempFile';
use vars qw($VERSION);
$VERSION='0.37';

=head1 NAME

HTML::Display::Phoenix - display HTML through Phoenix

=head1 SYNOPSIS

=for example begin

  my $browser = HTML::Display->new();
  $browser->display("<html><body><h1>Hello world!</h1></body></html>");

=for example end

=cut

sub browsercmd { "phoenix %s" };

1;
